<?php

class NewenlistController extends Controller {

    /**
     * @var string the default layout for the views. Defaults to '//layouts/column2', meaning
     * using two-column layout. See 'protected/views/layouts/column2.php'.
     */
    public $layout = '//layouts/column2';

    /**
     * @return array action filters
     */
    public function filters() {
        return array(
            'accessControl', // perform access control for CRUD operations
            'postOnly + delete', // we only allow deletion via POST request
        );
    }

    /**
     * Specifies the access control rules.
     * This method is used by the 'accessControl' filter.
     * @return array access control rules
     */
    public function accessRules() {
        return array(
            array('allow', // allow all users to perform 'index' and 'view' actions
                'actions' => array('index', 'view'),
                'users' => array('*'),
            ),
            array('allow', // allow authenticated user to perform 'create' and 'update' actions
                'actions' => array('create', 'update'),
                'users' => array('@'),
            ),
            array('allow', // allow admin user to perform 'admin' and 'delete' actions
                'actions' => array('admin', 'delete', 'rozvrh', 'admincreate'),
                'users' => array('admin.pez@bighuggym.com'),
            ),
            array('deny', // deny all users
                'users' => array('*'),
            ),
        );
    }

    /**
     * Displays a particular model.
     * @param integer $id the ID of the model to be displayed
     */
    public function actionView($id) {
        $this->render('view', array(
            'model' => $this->loadModel($id),
        ));
    }

    /**
     * Creates a new model.
     * If creation is successful, the browser will be redirected to the 'view' page.
     */
    public function actionCreate() {
        $model = new Newenlist;

        // Uncomment the following line if AJAX validation is needed
        // $this->performAjaxValidation($model);

        if (isset($_POST['Newenlist'])) {
            $model->attributes = $_POST['Newenlist'];
            if ($model->save())
                $this->redirect(array('view', 'id' => $model->ID));
        }

        $this->render('create', array(
            'model' => $model,
        ));
    }

    /**
     * Updates a particular model.
     * If update is successful, the browser will be redirected to the 'view' page.
     * @param integer $id the ID of the model to be updated
     */
    public function actionUpdate($id) {
        $model = $this->loadModel($id);

        // Uncomment the following line if AJAX validation is needed
        // $this->performAjaxValidation($model);

        if (isset($_POST['Newenlist'])) {
            $model->attributes = $_POST['Newenlist'];
            if ($model->save())
                $this->redirect(array('view', 'id' => $model->ID));
        }

        $this->render('update', array(
            'model' => $model,
        ));
    }

    /**
     * Deletes a particular model.
     * If deletion is successful, the browser will be redirected to the 'admin' page.
     * @param integer $id the ID of the model to be deleted
     */
    public function actionDelete($id) {
        $this->loadModel($id)->delete();

        // if AJAX request (triggered by deletion via admin grid view), we should not redirect the browser
        if (!isset($_GET['ajax']))
            $this->redirect(isset($_POST['returnUrl']) ? $_POST['returnUrl'] : array('admin'));
    }

    /**
     * Lists all models.
     */
    public function actionIndex() {
        $dataProvider = new CActiveDataProvider('Newenlist');
        $this->render('index', array(
            'dataProvider' => $dataProvider,
        ));
    }

    /**
     * Manages all models.
     */
    public function actionAdmin() {
        $model = new Newenlist('search');
        $model->unsetAttributes();  // clear any default values
        if (isset($_GET['Newenlist']))
            $model->attributes = $_GET['Newenlist'];

        $this->render('admin', array(
            'model' => $model,
        ));
    }

    public function actionRozvrh() {
        //$new_enlist = new Newenlist('rozvrh');
        $vsetky_roz = Newtimetable::model()->with(array('trainer0'))->findAll();
        $vsetky_prih = Newenlist::model()->findAll();


        $this->render('rozvrh', array('rozvrhy' => $vsetky_roz, 'prihlasenia' => $vsetky_prih));
    }

    public function actionAdmincreate($tid) {
        $model = new Newenlist;
        $enlisted = Newenlist::model()->findAllByAttributes(array(
            'ID_timet' => $tid,
        ));

        $klinks = array();
        foreach ($enlisted as $value) {
            $tkid = Kids::model()->findByPK($value->ID_kid);
            array_push($klinks, CHtml::link($tkid->surname . ' ' . $tkid->name . '<br />', array('kids/view', 'id' => $value->ID_kid), array('target' => '_blank')));
            //$klinks = CHtml::link( $tkid->surname.' '.$tkid->name.'<br />', array('kids/view','id'=>$value->ID_kid));
        }

        // Uncomment the following line if AJAX validation is needed
        // $this->performAjaxValidation($model);

        if (isset($_POST['Newenlist'])) {
            $model->attributes = $_POST['Newenlist'];
            if ($model->save())
                $this->redirect(array('admincreate', 'tid' => $tid));
        }

        $this->render('admincreate', array(
            'model' => $model,
            'links' => $klinks,
            'ttid' => $tid,
        ));
    }

    /**
     * Returns the data model based on the primary key given in the GET variable.
     * If the data model is not found, an HTTP exception will be raised.
     * @param integer $id the ID of the model to be loaded
     * @return Newenlist the loaded model
     * @throws CHttpException
     */
    public function loadModel($id) {
        $model = Newenlist::model()->findByPk($id);
        if ($model === null)
            throw new CHttpException(404, 'The requested page does not exist.');
        return $model;
    }

    /**
     * Performs the AJAX validation.
     * @param Newenlist $model the model to be validated
     */
    protected function performAjaxValidation($model) {
        if (isset($_POST['ajax']) && $_POST['ajax'] === 'newenlist-form') {
            echo CActiveForm::validate($model);
            Yii::app()->end();
        }
    }

}
