<?php

/**
 * This is the model class for table "hours".
 *
 * The followings are the available columns in table 'hours':
 * @property integer $ID
 * @property string $date
 * @property integer $ID_timet
 * @property string $week_day
 * @property string $time_start
 * @property string $time_end
 * @property string $lesson
 * @property integer $trainer
 * @property integer $trainer_alt
 * @property integer $ID_kids
 * @property string $name
 * @property string $surname
 * @property integer $present
 * @property integer $tryout
 * @property string $notes
 * @property string $cur_timestamp
 */
class Hours extends CActiveRecord
{
	/**
	 * @return string the associated database table name
	 */
	public function tableName()
	{
		return 'hours';
	}

	/**
	 * @return array validation rules for model attributes.
	 */
	public function rules()
	{
		// NOTE: you should only define rules for those attributes that
		// will receive user inputs.
		return array(
			array('date, ID_timet, week_day, time_start, time_end, lesson, trainer, ID_kids, name, surname', 'required'),
			array('ID_timet, trainer, trainer_alt, ID_kids, present, tryout', 'numerical', 'integerOnly'=>true),
			array('week_day', 'length', 'max'=>15),
			array('lesson, name, surname', 'length', 'max'=>45),
			array('notes', 'safe'),
			// The following rule is used by search().
			// @todo Please remove those attributes that should not be searched.
			array('ID, date, ID_timet, week_day, time_start, time_end, lesson, trainer, trainer_alt, ID_kids, name, surname, present, tryout, notes, cur_timestamp', 'safe', 'on'=>'search'),
		);
	}

	/**
	 * @return array relational rules.
	 */
	public function relations()
	{
		// NOTE: you may need to adjust the relation name and the related
		// class name for the relations automatically generated below.
		return array(
		);
	}

	/**
	 * @return array customized attribute labels (name=>label)
	 */
	public function attributeLabels()
	{
		return array(
			'ID' => 'ID hodiny',
			'date' => 'Dátum',
			'ID_timet' => 'ID rozvrhu',
			'week_day' => 'Deň v týždni',
			'time_start' => 'Začiatok',
			'time_end' => 'Koniec',
			'lesson' => 'Kurz',
			'trainer' => 'ID trénera',
			'trainer_alt' => 'ID trénera 2',
			'ID_kids' => 'ID dieťaťa',
			'name' => 'Meno',
			'surname' => 'Priezvisko',
			'present' => 'Účasť na hodine',
			'tryout' => 'Skúšobná hodina',
			'notes' => 'Poznámky',
			'cur_timestamp' => 'Čas záznamu',                    
		);
	}

	/**
	 * Retrieves a list of models based on the current search/filter conditions.
	 *
	 * Typical usecase:
	 * - Initialize the model fields with values from filter form.
	 * - Execute this method to get CActiveDataProvider instance which will filter
	 * models according to data in model fields.
	 * - Pass data provider to CGridView, CListView or any similar widget.
	 *
	 * @return CActiveDataProvider the data provider that can return the models
	 * based on the search/filter conditions.
	 */
	public function search()
	{
		// @todo Please modify the following code to remove attributes that should not be searched.

		$criteria=new CDbCriteria;

		$criteria->compare('ID',$this->ID);
		$criteria->compare('date',$this->date,true);
		$criteria->compare('ID_timet',$this->ID_timet);
		$criteria->compare('week_day',$this->week_day,true);
		$criteria->compare('time_start',$this->time_start,true);
		$criteria->compare('time_end',$this->time_end,true);
		$criteria->compare('lesson',$this->lesson,true);
		$criteria->compare('trainer',$this->trainer);
		$criteria->compare('trainer_alt',$this->trainer_alt);
		$criteria->compare('ID_kids',$this->ID_kids);
		$criteria->compare('name',$this->name,true);
		$criteria->compare('surname',$this->surname,true);
		$criteria->compare('present',$this->present);
		$criteria->compare('tryout',$this->tryout);
		$criteria->compare('notes',$this->notes,true);
		$criteria->compare('cur_timestamp',$this->cur_timestamp,true);

		return new CActiveDataProvider($this, array(
			'criteria'=>$criteria,
      'pagination'=>array(
        'pageSize'=>100,
      ),
		));
	}

	/**
	 * Returns the static model of the specified AR class.
	 * Please note that you should have this exact method in all your CActiveRecord descendants!
	 * @param string $className active record class name.
	 * @return Hours the static model class
	 */
	public static function model($className=__CLASS__)
	{
		return parent::model($className);
	}
}
