<?php

/**
 * This is the model class for table "payments".
 *
 * The followings are the available columns in table 'payments':
 * @property integer $ID
 * @property integer $ID_kid
 * @property string $date
 * @property integer $trimester
 * @property integer $n_of_hours
 * @property integer $prize_per_h
 * @property integer $discount
 * @property string $VS
 * @property integer $payed
 */
class Payments extends CActiveRecord {

    public $kid_name_s;
    public $kid_surname_s;
    
    /**
     * @return string the associated database table name
     */
    public function tableName() {
        return 'payments';
    }

    /**
     * @return array validation rules for model attributes.
     */
    public function rules() {
        // NOTE: you should only define rules for those attributes that
        // will receive user inputs.
        return array(
            array('ID_kid, date, trimester, n_of_hours, prize_per_h, discount, VS', 'required'),
            array('ID_kid, trimester, n_of_hours, prize_per_h, discount, payed', 'numerical', 'integerOnly' => true),
            array('VS', 'length', 'max' => 45),
            // The following rule is used by search().
            // @todo Please remove those attributes that should not be searched.
            array('ID, ID_kid, date, trimester, n_of_hours, prize_per_h, discount, VS, payed, kid_name_s, kid_surname_s', 'safe', 'on' => 'search'),
        );
    }

    /**
     * @return array relational rules.
     */
    public function relations() {
        // NOTE: you may need to adjust the relation name and the related
        // class name for the relations automatically generated below.
        return array(
            'kid' => array(self::BELONGS_TO, 'Kids', 'ID_kid'),
            /*'par' => array(self::BELONGS_TO, 'Users', function(){
                $kid = Kids::model()->findbyPk('ID_kid');
                return Users::model()->findByPk()
            }),*/
            'trimester_' => array(self::BELONGS_TO, 'Semesters', 'trimester'),
        );
    }

    /**
     * @return array customized attribute labels (name=>label)
     */
    public function attributeLabels() {
        return array(
            'ID' => 'ID Platby',
            'ID_kid' => 'ID Dieťaťa',
            'date' => 'Dátum',
            'trimester' => 'Trimester',
            'n_of_hours' => 'Počet hodín',
            'prize_per_h' => 'Cena za hodinu',
            'discount' => 'Zľava',
            'VS' => 'Variabilný symbol',
            'payed' => 'Zaplatené',
        );
    }

    /**
     * Retrieves a list of models based on the current search/filter conditions.
     *
     * Typical usecase:
     * - Initialize the model fields with values from filter form.
     * - Execute this method to get CActiveDataProvider instance which will filter
     * models according to data in model fields.
     * - Pass data provider to CGridView, CListView or any similar widget.
     *
     * @return CActiveDataProvider the data provider that can return the models
     * based on the search/filter conditions.
     */
    public function search() {
        // @todo Please modify the following code to remove attributes that should not be searched.

        $criteria = new CDbCriteria;
        
        $criteria->with = array('kid');
        
        $criteria->addCondition('kid.id IS NOT NULL');
        $criteria->compare('kid.name',$this->kid_name_s ,true);
        $criteria->compare('kid.surname',$this->kid_surname_s ,true);
        
        $criteria->compare('t.ID', $this->ID);
        $criteria->compare('ID_kid', $this->ID_kid);
        $criteria->compare('date', $this->date, true);
        $criteria->compare('trimester', $this->trimester);
        $criteria->compare('n_of_hours', $this->n_of_hours);
        $criteria->compare('prize_per_h', $this->prize_per_h);
        $criteria->compare('discount', $this->discount);
        $criteria->compare('VS', $this->VS, true);
        $criteria->compare('payed', $this->payed);


        return new CActiveDataProvider($this, array(
            'criteria' => $criteria,
            'pagination' => array(
                'pageSize' => 50,
            ),
        ));
    }

    /**
     * Returns the static model of the specified AR class.
     * Please note that you should have this exact method in all your CActiveRecord descendants!
     * @param string $className active record class name.
     * @return Payments the static model class
     */
    public static function model($className = __CLASS__) {
        return parent::model($className);
    }

}
